package com.hzya.frame.plugin.oa.payment.plugin;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.oa.payment.dao.IPaymentDao;
import com.hzya.frame.plugin.oa.payment.dao.IPaymentDetailsDao;
import com.hzya.frame.plugin.oa.payment.entity.PaymentDetailsEntity;
import com.hzya.frame.plugin.oa.payment.entity.PaymentEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.uuid.UUIDUtils;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.Date;
import java.util.List;

public class CbsResultToOAPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(CbsResultToOAPluginInitializer.class);

    @Autowired
    private IPaymentDao paymentDao;
    @Autowired
    private IPaymentDetailsDao paymentDetailsDao;

    @Value("${zt.url}")
    private String url;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;


    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "CbsResultToOAPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "CBS支付结果回写OA";
    }

    @Override
    public String getPluginLabel() {
        return "CbsResultToOAPluginInitializer";
    }

    @Override
    public String getPluginType() {
        return "1";
    }
    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) {
        try {
            logger.info("======开始执行CBS支付结果回写OA========");
            //重试方法
            if (null != requestJson) {
                //如果这个id不为空，说明是重试的
                String id = requestJson.getString("integration_task_living_details_id");
                //执行重新发送
                PaymentEntity paymentEntity = new PaymentEntity();
                paymentEntity.setDataSourceCode("");
                if (StrUtil.isNotEmpty(id)) {
                    paymentEntity.setId(id);
                }
                //查询没有支付成功的数据
                List<PaymentEntity> paymentEntities = paymentDao.queryPaymentOAResult(paymentEntity);
                if(paymentEntities == null || paymentEntities.size() == 0){
                    logger.info("=====OA中没有需要查询支付状态的数据==========");
                    return BaseResult.getSuccessMessageEntity("查询成功");
                }
                for (PaymentEntity payment : paymentEntities) {
                    payment.setDataSourceCode("");
                    JSONObject jsonObject=new JSONObject();


                    String result = HttpRequest.post(url).
                            header("appId", "").
                            header("apiCode", "").
                            header("publicKey", "ZJYAQ/VtQ66PqKXlV0EowrrlKkhBHYgS/Zk39Q5ezIQne51Ce7eDIk+3zDUT+v578prj").
                            header("secretKey", "iLLk424Bmzknbu+ROeJoiVDMYY5EFXtbZY/aU13HmVYIiQrIw9c0Ag4ipxbfpUqqj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(jsonObject.toString()).
                            execute().
                            body();
                    logger.info("========CBS支付结果回写OA的返回参数为:{}=========",result);
                    JSONObject resultJson = JSONObject.parseObject(result);
                    if(!resultJson.getBoolean("flag")){
                        JSONObject attribute = resultJson.getJSONObject("attribute");
                        if("".equals(attribute.getString(""))){
                            //修改oa付款单支付状态
                            payment.setOaResult("");
                            paymentDao.updatePaymentOAResult(payment);
                        }
                    }
                }
            }
        }catch(Exception e){
            logger.info("======执行CBS支付结果回写OA失败:{}========", e.getMessage());
            e.printStackTrace();
        }
        return BaseResult.getFailureMessageEntity("CBS支付结果回写OA执行失败");
    }

    private void saveTaskLivingDetails(String rootAppPk,String rootAppBill,String rootAppNewData,String newTransmitInfo,boolean flag) {
        try {
            IntegrationTaskLivingDetailsEntity integrationTaskLivingDetailsEntity = new IntegrationTaskLivingDetailsEntity();
            integrationTaskLivingDetailsEntity.setId(UUIDUtils.getUUID());
            integrationTaskLivingDetailsEntity.setSts("Y");
            integrationTaskLivingDetailsEntity.setCreate_user_id("1");
            integrationTaskLivingDetailsEntity.setModify_user_id("1");
            integrationTaskLivingDetailsEntity.setCreate_time(new Date());
            integrationTaskLivingDetailsEntity.setModify_time(new Date());
            integrationTaskLivingDetailsEntity.setOrg_id("0");
            integrationTaskLivingDetailsEntity.setCompanyId("0");
            integrationTaskLivingDetailsEntity.setRootAppPk(rootAppPk);
            integrationTaskLivingDetailsEntity.setRootAppBill(rootAppBill);
            integrationTaskLivingDetailsEntity.setPluginId("CbsResultToOAPluginInitializer");
            integrationTaskLivingDetailsEntity.setRootAppNewData(rootAppNewData);
            integrationTaskLivingDetailsEntity.setNewTransmitInfo(newTransmitInfo);
            if(flag){
                taskLivingDetailsService.saveLogToSuccess(integrationTaskLivingDetailsEntity);
            }else {
                taskLivingDetailsService.saveLogToFail(integrationTaskLivingDetailsEntity);
            }
        }catch (Exception e){
            logger.info("保存日志到集成任务日志明细中失败:{}",e.getMessage());
        }
    }
}
