package com.hzya.frame.plugin.oa.payment.plugin;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.oa.payment.dao.IPaymentDao;
import com.hzya.frame.plugin.oa.payment.dao.IPaymentDetailsDao;
import com.hzya.frame.plugin.oa.payment.entity.PaymentDetailsEntity;
import com.hzya.frame.plugin.oa.payment.entity.PaymentEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.uuid.UUIDUtils;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class PaymentToOAPluginInitializer extends PluginBaseEntity {
    Logger logger = LoggerFactory.getLogger(PaymentToOAPluginInitializer.class);

    @Autowired
    private IPaymentDao paymentDao;
    @Autowired
    private IPaymentDetailsDao paymentDetailsDao;

    @Value("${zt.url}")
    private String url;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;


    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "PaymentToOAPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "NCC付款单传递OA";
    }

    @Override
    public String getPluginLabel() {
        return "PaymentToOAPluginInitializer";
    }

    @Override
    public String getPluginType() {
        return "1";
    }
    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) {
        try {
            logger.info("======开始执行NCC付款单传递OA========");
            //重试方法
            if (null != requestJson) {
                //如果这个id不为空，说明是重试的
                String id = requestJson.getString("integration_task_living_details_id");
                //执行重新发送
                PaymentEntity paymentEntity = new PaymentEntity();
                paymentEntity.setDataSourceCode("");
                if (StrUtil.isNotEmpty(id)) {
                    paymentEntity.setId(id);
                }
                //查询ncc需要传递OA的数据
                List<PaymentEntity> paymentEntities = paymentDao.query(paymentEntity);
                if(paymentEntities == null || paymentEntities.size() == 0){
                    logger.info("=====没有需要从NCC传递到OA的付款单==========");
                    return BaseResult.getSuccessMessageEntity("查询成功");
                }
                for (PaymentEntity payment : paymentEntities) {
                    JSONObject jsonObject=new JSONObject();
                    JSONObject jsonMain=new JSONObject();
                    JSONArray jsonArray=new JSONArray();
                    jsonObject.put("应付财务组织",payment.getPkOrg());
                    jsonObject.put("红冲标志",payment.getIsreded());
                    jsonObject.put("付款类型",payment.getPkTradetypeid());
                    jsonObject.put("单据编号",payment.getBillno());
                    jsonObject.put("单据日期",payment.getBilldate());
                    jsonObject.put("单据状态",payment.getBillstatus());
                    jsonObject.put("发起人",payment.getBillmaker());
                    jsonObject.put("业务流程",payment.getPkBusitype());
                    jsonObject.put("原币金额",payment.getMoney());
                    jsonObject.put("组织本币金额",payment.getLocalMoney());
                    jsonObject.put("生效状态",payment.getEffectstatus());
                    jsonObject.put("部门",payment.getPkDeptid());
                    jsonObject.put("业务员",payment.getPkPsndoc());
                    jsonObject.put("供应商",payment.getSupplier());
                    jsonObject.put("币种",payment.getPkCurrtype());
                    jsonObject.put("收支项目",payment.getPkSubjcode());
                    jsonObject.put("结算方式",payment.getPkBalatype());
                    jsonObject.put("往来对象",payment.getObjtype());
                    jsonObject.put("付款银行账户",payment.getPayaccount());
                    jsonObject.put("收款银行账户",payment.getRecaccount());
                    jsonObject.put("现金账户",payment.getCashaccount());
                    jsonObject.put("审批状态",payment.getApprovestatus());
                    jsonObject.put("客户",payment.getCustomer());
                    jsonMain.put("formmain_0260",jsonObject);
                    PaymentDetailsEntity paymentDetailsEntity=new PaymentDetailsEntity();
                    paymentDetailsEntity.setDataSourceCode("");
                    paymentDetailsEntity.setTopBillid(payment.getPkPaybill());
                    //查询NCC付款单明细
                    List<PaymentDetailsEntity> paymentDetailsEntities = paymentDetailsDao.query(paymentDetailsEntity);
                    if(paymentDetailsEntities == null || paymentDetailsEntities.size() == 0){
                        logger.info("=====没有需要从NCC传递到OA的付款单明细数据==========");
                    }else{
                        for (PaymentDetailsEntity detailsEntity : paymentDetailsEntities) {
                              JSONObject jsonDetails=new JSONObject();
                              jsonDetails.put("付款性质",detailsEntity.getPrepay());
                              jsonDetails.put("物料",detailsEntity.getMaterial());
                              jsonDetails.put("供应商-明细表",detailsEntity.getSupplier());
                              jsonDetails.put("挂起标志",detailsEntity.getPausetransact());
                              jsonDetails.put("往来对象-明细表",detailsEntity.getObjtype());
                              jsonDetails.put("票据类型",detailsEntity.getChecktype());
                              jsonDetails.put("摘要",detailsEntity.getScomment());
                              jsonDetails.put("币种-明细表",detailsEntity.getPkCurrtype());
                              jsonDetails.put("组织本币汇率-明细表",detailsEntity.getRate());
                              jsonDetails.put("部门-明细表",detailsEntity.getPkDeptid());
                              jsonDetails.put("业务员-明细表",detailsEntity.getPkPsndoc());
                              jsonDetails.put("借方原币金额",detailsEntity.getMoneyDe());
                              jsonDetails.put("组织本币金额-借方",detailsEntity.getLocalMoneyDe());
                              jsonDetails.put("借方原币无税金额",detailsEntity.getNotaxDe());
                              jsonDetails.put("税率",detailsEntity.getTaxrate());
                              jsonDetails.put("结算方式-明细表",detailsEntity.getPkBalatype());
                              jsonDetails.put("票据号",detailsEntity.getCheckno());
                              jsonDetails.put("付款银行账户-明细表",detailsEntity.getPayaccount());
                              jsonDetails.put("收款银行账户-明细表",detailsEntity.getRecaccount());
                              jsonDetails.put("现金账户-明细表",detailsEntity.getCashaccount());
                              jsonDetails.put("集团本币无税金额-借方",detailsEntity.getGroupnotaxDe());
                              jsonDetails.put("全局本币无税金额-借方",detailsEntity.getGlobalnotaxDe());
                              jsonDetails.put("客户-明细表",detailsEntity.getCustomer());
                              jsonDetails.put("付款业务类型",detailsEntity.getPkRecpaytype());
                              jsonDetails.put("税码",detailsEntity.getTaxcodeid());
                              jsonDetails.put("直联电票",detailsEntity.getDirectCheckno());
                              jsonArray.add(jsonDetails);
                        }
                    }
                    jsonMain.put("formson_0261",jsonArray);
                    Map<String, Object> map = new HashMap<String, Object>();
                    map.put("appName", "collaboration");
                    Map<String, Object> data1 = new HashMap<String, Object>();
                    data1.put("templateCode", "formmain_0260");
                    data1.put("draft", "1");
                    data1.put("data", jsonMain);
                    map.put("data", data1);
                    logger.info("========NCC付款单传递OA的请求参数为:{}=========",map);
                    //发送数据
                    String result = HttpRequest.post(url).
                            header("appId", "800064").
                            header("apiCode", "8000640000").
                            header("publicKey", "ZJYAQ/VtQ66PqKXlV0EowrrlKkhBHYgS/Zk39Q5ezIQne51Ce7eDIk+3zDUT+v578prj").
                            header("secretKey", "iLLk424Bmzknbu+ROeJoiVDMYY5EFXtbZY/aU13HmVYIiQrIw9c0Ag4ipxbfpUqqj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=").
                            body(map.toString()).
                            execute().
                            body();
                    logger.info("========NCC付款单传递OA的返回参数为:{}=========",result);
                    JSONObject resultJson = JSONObject.parseObject(result);
                    if(!resultJson.getBoolean("flag")){
                        JSONObject attribute = resultJson.getJSONObject("attribute");
                        if("0".equals(attribute.getString("code"))){
                            //修改NCC付款单推送状态
                        }
                    }
                }
                logger.info("=======NCC付款单传递OA执行成功=======");
                return BaseResult.getSuccessMessageEntity("NCC付款单传递OA执行成功");
            }
        }catch (Exception e){
            logger.info("======执行NCC付款单传递OA失败:{}========", e.getMessage());
            e.printStackTrace();
        }
        return BaseResult.getFailureMessageEntity("NCC付款单传递OA执行失败");
    }


    private void saveTaskLivingDetails(String rootAppPk,String rootAppBill,String rootAppNewData,String newTransmitInfo,boolean flag) {
        try {
            IntegrationTaskLivingDetailsEntity integrationTaskLivingDetailsEntity = new IntegrationTaskLivingDetailsEntity();
            integrationTaskLivingDetailsEntity.setId(UUIDUtils.getUUID());
            integrationTaskLivingDetailsEntity.setSts("Y");
            integrationTaskLivingDetailsEntity.setCreate_user_id("1");
            integrationTaskLivingDetailsEntity.setModify_user_id("1");
            integrationTaskLivingDetailsEntity.setCreate_time(new Date());
            integrationTaskLivingDetailsEntity.setModify_time(new Date());
            integrationTaskLivingDetailsEntity.setOrg_id("0");
            integrationTaskLivingDetailsEntity.setCompanyId("0");
            integrationTaskLivingDetailsEntity.setRootAppPk(rootAppPk);
            integrationTaskLivingDetailsEntity.setRootAppBill(rootAppBill);
            integrationTaskLivingDetailsEntity.setPluginId("PaymentToOAPluginInitializer");
            integrationTaskLivingDetailsEntity.setRootAppNewData(rootAppNewData);
            integrationTaskLivingDetailsEntity.setNewTransmitInfo(newTransmitInfo);
            if(flag){
                taskLivingDetailsService.saveLogToSuccess(integrationTaskLivingDetailsEntity);
            }else {
                taskLivingDetailsService.saveLogToFail(integrationTaskLivingDetailsEntity);
            }
        }catch (Exception e){
            logger.info("保存日志到集成任务日志明细中失败:{}",e.getMessage());
        }
    }

}
